#!/bin/sh

# This script should be called from connector_manager.sh, and accepts the following parameters:
#  start_myconnector.sh <CONNECTORNAME> <SERVERNAME> <OPTIONAL ADDITIONAL PARAMETERS>
#
#  Any line that has the #   <-- Check on it should be reviewed for your connector
#
#The file CWSharedEnv.sh defines the following in it's classpath, so there is no need to override any of these:
#Please go look at this file, on the solaris build, it is in the $CROSSWORLDS/setup directory.
#All of these are bundeled together into the CLASSPATH variable which is then exported for your use
#It defines things such as:
#CORECW
#RSA 
#CWUTILS 
#XML_PARSER 
#DATAHANDLERS 
#MQ 
#ORB1 
#ORB2 
#JVM_FLAGS 
#JRT 
#JAVA_SECURITY 
#WEBLOGIC 
#
################################################
# General connector variable initialization section
# No changes should be necessary
# set CONNECTOR_TYPE  -- This is needed to differentate Java from C++ conncetors 
# set CONDIR  the directory where the specific connector resides, then change to this directory
# set CONNAME the name to be the application connector that is starting
# set SERVER  the server name to be the interchange that is being targeted
# set CONJAR to the fullpath of the connector .jar file.

# Change this to point to your Oracle home directorys
ORACLE_HOME=/export/home/oracle/product/8.0.6
TNS_ADMIN=${ORACLE_HOME}/network/admin
export ORACLE_HOME TNS_ADMIN
  
# set the name to be the application connector that is starting
CONNAME=$1

# set the server name to be the interchange that is being targeted
SERVER=$2

# set the directory where the specific connector resides
CONDIR=${CROSSWORLDS}/connectors/${CONNAME}

################################################
# Connector specific variable initialization section
# Set your Connector agent here 

#The following two sections tell the script what language the connector was written in,
# and help it make the correct calls. 
#Please enable one of the next sections

#For C++ connectors enable the following
CONNECTOR_TYPE="-d"                                                             #   <-- Check
CONNECTOR_AGENT=${CONNAME}                                                      #   <-- Check
CONJAR=""
LOCAL_JVM_FLAGS=${CONN_CPP_JVM_FLAGS}

#For Java connectors enable the following
#CONNECTOR_TYPE="-l"                                                                     #   <-- Check
#CONNECTOR_AGENT=com.crossworlds.connectors.YourConnector.YourConnectorConnectorAgent    #   <-- Check
#CONJAR=${CONDIR}/CW${CONNAME}.jar
#LOCAL_JVM_FLAGS=${CONN_JAVA_JVM_FLAGS}

# Set any Connector specific start options here (Like -t or -fno etc.)
CON_START_OPTIONS=" "                                                            #   <-- Check

# Set any connector specific Variables here
#CON_SPEC_JAR_ONE=${CONDIR}/abc.jar                                               #   <-- Check
#CON_SPEC_JAR_TWO=${CONDIR}/def.jar                                               #   <-- Check

# Set Conn specific classpath here 
#Any specific variables defined above need to be added to the CON_SPECIFIC_CLASSPATH below.
CON_SPECIFIC_CLASSPATH=${CON_SPEC_JAR_ONE}:${CON_SPEC_JAR_TWO}                   #   <-- Check  

# Begin as per the new run-time code split
if [ -f ${CROSSWORLDS}/wbiart/wbiart.jar ]
then
# Using the new run-time code split
. ${CROSSWORLDS}/bin/CWConnEnv.sh

# All the variables that need to be passed to the callee need to be defined here
JCLASSES=
LibPath=${CONDIR}:${ORACLE_HOME}/lib
ExtDirs=
JVMArgs=

export JCLASSES
export LibPath
export ExtDirs
export JVMArgs

# Call the base start_adapter.sh to start the connector
exec start_adapter.sh ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME} -s${SERVER} ${CON_START_OPTIONS} $3 $4

else
. ${CROSSWORLDS}/bin/CWConnEnv.sh

LD_LIBRARY_PATH=${CONDIR}:${ORACLE_HOME}/lib:${LD_LIBRARY_PATH}
export LD_LIBRARY_PATH

CWCLASSES=${CWCLASSES}
CLASSPATH=${CON_SPECIFIC_CLASSPATH}:${CWCLASSES}
echo $CLASSPATH
${CROSSWORLDS}/bin/check_path.sh "$CLASSPATH"
exec ${CWJAVA} ${LOCAL_JVM_FLAGS}  -Djava.library.path=${LD_LIBRARY_PATH} -Djava.ext.dirs=${JRE_EXT_DIRS} -DORACLE_HOME=${ORACLE_HOME} -DTNS_ADMIN=${TNS_ADMIN} -classpath ${CLASSPATH} AppEndWrapper ${CONNECTOR_TYPE}${CONNECTOR_AGENT} -n${CONNAME}Connector -s${SERVER} ${CON_START_OPTIONS}  $3 $4 $5 $6 $7 $8 $9

fi
#closed the new runtime split above.
